| connectSPCSUser | R Documentation |
connectSPCSUser() connects your Posit Connect account to the rsconnect
package so it can deploy and manage applications on your behalf.
Configure a
connections.toml file
in the appropriate location.
SPCS deployments require both Snowflake authentication (via the connection name) and a Posit Connect API key. The Snowflake token provides proxied authentication to reach the Connect server, while the API key identifies the user to Connect itself.
If snowflakeConnectionName is not provided, rsconnect will attempt to
use the default Snowflake connection from the connections.toml file,
provided that the account matches the Connect server's URL.
Supported servers: Posit Connect servers
connectSPCSUser(
account = NULL,
server = NULL,
apiKey,
snowflakeConnectionName = NULL,
quiet = FALSE
)
account |
A name for the account to connect. |
server |
The server to connect to. |
apiKey |
The API key used to authenticate the user |
snowflakeConnectionName |
Name of the Snowflake connection in
|
quiet |
Whether or not to show messages and prompts while connecting the account. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.