Generate a short name (identifier) for an application given an application title.
Details
This function modifies the title until it forms a suitable application name. Suitable application names are 3 - 64 characters long and contain only alphanumeric characters.
The function is intended to be used to find a name for a new application.
If appPath and account are both specified, then the returned
name will also be unique among locally known deployments of the directory
(note that it is not guaranteed to be unique on the server). This behavior
can be disabled by setting unique = FALSE.