| removeAuthorizedUser | R Documentation |
Remove authorized user from an application
Supported servers: ShinyApps, Posit Connect Cloud
removeAuthorizedUser(
user,
appDir = getwd(),
appName = NULL,
contentId = NULL,
account = NULL,
server = NULL
)
user |
The user to remove. Can be id or email address. |
appDir |
Directory containing application. Defaults to current working directory. |
appName |
Name of application. |
contentId |
On Posit Connect Cloud, the content ID to manage, taken from
the content URL
( |
account, server |
Uniquely identify a remote server with either your
user Use |
This function works for ShinyApps and Posit Connect Cloud.
On Posit Connect Cloud, the content is resolved from the local deployment
record under appDir, which defaults to the working directory. Pass
appDir to point at the project directory that contains the
rsconnect/ deployment record. appName selects among multiple records in
the same directory. Alternatively, pass contentId to target the
content directly, without a local deployment record.
addAuthorizedUser() and showUsers()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.