| addAuthorizedUser | R Documentation |
Add authorized user to application
Supported servers: ShinyApps, Posit Connect Cloud
addAuthorizedUser(
email,
appDir = getwd(),
appName = NULL,
contentId = NULL,
account = NULL,
server = NULL,
sendEmail = NULL,
emailMessage = NULL
)
email |
Email address of user to add. |
appDir |
Directory containing application. Defaults to current working directory. |
appName |
Name of application. |
contentId |
On Posit Connect Cloud, the content ID to manage, taken from
the content URL
( |
account, server |
Uniquely identify a remote server with either your
user Use |
sendEmail |
Send an email letting the user know the application has been shared with them. |
emailMessage |
Optional character vector of length 1 containing a custom message to send in email invitation. Defaults to NULL, which will use default invitation message. |
This function works for ShinyApps and Posit Connect Cloud. On Posit
Connect Cloud, the content's account must be an organization account.
The sendEmail argument is ignored on Posit Connect Cloud;
PCC always sends an invitation email.
On Posit Connect Cloud, the content is resolved from the local deployment
record under appDir, which defaults to the working directory. Pass
appDir to point at the project directory that contains the
rsconnect/ deployment record. appName selects among multiple records in
the same directory. Alternatively, pass contentId to target the
content directly, without a local deployment record.
removeAuthorizedUser() and showUsers()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.