Add authorized user to application
Supported servers: ShinyApps, Posit Connect Cloud
addAuthorizedUser(
email,
appDir = getwd(),
appName = NULL,
contentId = NULL,
account = NULL,
server = NULL,
sendEmail = NULL,
emailMessage = NULL
)Email address of user to add.
Directory containing application. Defaults to current working directory.
Name of application.
On Posit Connect Cloud, the content ID to manage, taken from
the content URL
(https://connect.posit.cloud/{account}/content/{contentId}). When
supplied, appDir and appName are ignored and no local
deployment record is required. Not supported on shinyapps.io.
Uniquely identify a remote server with either your
user account, the server name, or both. If neither are supplied, and
there are multiple options, you'll be prompted to pick one.
Use accounts() to see the full list of available options.
Send an email letting the user know the application has been shared with them.
Optional character vector of length 1 containing a custom message to send in email invitation. Defaults to NULL, which will use default invitation message.
removeAuthorizedUser() and showUsers()