powered by
These functions manage the list of known servers:
addServer() registers a Posit connect server. Once it has been registered, you can connect to an account on the server using connectUser().
addServer()
connectUser()
removeServer() removes a server from the registry.
removeServer()
addServerCertificate() adds a certificate to a server.
addServerCertificate()
Supported servers: Posit Connect servers
addServer( url, name = NULL, certificate = NULL, validate = TRUE, snowflakeConnectionName = NULL, quiet = FALSE )removeServer(name = NULL)addServerCertificate(name, certificate, quiet = FALSE)
removeServer(name = NULL)
addServerCertificate(name, certificate, quiet = FALSE)
URL for the server. Can be a bare hostname like connect.mycompany.com or a url like http://posit.mycompany.com/connect.
connect.mycompany.com
http://posit.mycompany.com/connect
Server name. If omitted, the server hostname is used.
Optional. Either a path to certificate file or a character vector containing the certificate's contents.
Validate that url actually points to a Posit Connect server?
url
Name for the Snowflake connection in connections.toml to use for authentication or NULL to use the default (when applicable).
connections.toml
NULL
Suppress output and prompts where possible.
if (FALSE) { # register a local server addServer("http://myrsconnect/", "myserver") # list servers servers(local = TRUE) # connect to an account on the server connectUser(server = "myserver") }
Run the code above in your browser using DataLab