connectCloudClientCredentials: Register a Posit Connect Cloud account using OAuth client...

View source: R/accounts.R

connectCloudClientCredentialsR Documentation

Register a Posit Connect Cloud account using OAuth client credentials

Description

connectCloudClientCredentials() registers a Posit Connect Cloud account using an OAuth 2.0 client_credentials grant provided by the Posit Cloud auth service (https://login.posit.cloud/identity/credentials). Use this function to authenticate in non-interactive contexts.

Supported servers: Posit Connect Cloud servers

Usage

connectCloudClientCredentials(
  clientId,
  clientSecret,
  accountName,
  name = NULL,
  quiet = FALSE
)

Arguments

clientId

The OAuth client ID issued for a Posit Connect Cloud service account.

clientSecret

The OAuth client secret paired with clientId.

accountName

The Posit Connect Cloud account name to publish to. The credentials must grant publish permission on this account.

name

The local name to record the account under. Defaults to accountName.

quiet

Whether or not to show messages while connecting the account.

See Also

Other Account functions: accounts(), connectApiUser(), connectCloudUser(), setAccountInfo()


rsconnect documentation built on June 9, 2026, 1:09 a.m.