| connectCloudClientCredentials | R Documentation |
connectCloudClientCredentials() registers a Posit Connect Cloud account
using an OAuth 2.0 client_credentials grant provided by the Posit Cloud
auth service (https://login.posit.cloud/identity/credentials). Use this
function to authenticate in non-interactive contexts.
Supported servers: Posit Connect Cloud servers
connectCloudClientCredentials(
clientId,
clientSecret,
accountName,
name = NULL,
quiet = FALSE
)
clientId |
The OAuth client ID issued for a Posit Connect Cloud service account. |
clientSecret |
The OAuth client secret paired with |
accountName |
The Posit Connect Cloud account name to publish to. The credentials must grant publish permission on this account. |
name |
The local name to record the account under. Defaults to
|
quiet |
Whether or not to show messages while connecting the account. |
Other Account functions:
accounts(),
connectApiUser(),
connectCloudUser(),
setAccountInfo()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.