Learn R Programming

rsconnect (version 1.11.2)

resendInvitation: Resend invitation for invited users of an application

Description

Resend invitation for invited users of an application

Supported servers: ShinyApps, Posit Connect Cloud

Usage

resendInvitation(
  invite,
  regenerate = FALSE,
  appDir = getwd(),
  appName = NULL,
  contentId = NULL,
  account = NULL,
  server = NULL
)

Arguments

invite

The invitation to resend. Can be id or email address.

regenerate

Regenerate the invite code. Can be helpful is the invitation has expired.

appDir

Directory containing application. Defaults to current working directory.

appName

Name of application.

contentId

On Posit Connect Cloud, the content ID to manage, taken from the content URL (https://connect.posit.cloud/{account}/content/{contentId}). When supplied, appDir and appName are ignored and no local deployment record is required. Not supported on shinyapps.io.

account, server

Uniquely identify a remote server with either your user account, the server name, or both. If neither are supplied, and there are multiple options, you'll be prompted to pick one.

Use accounts() to see the full list of available options.

See Also

showInvited()